@@ -102,7 +102,7 @@ var matchFunctions = map[CheckAction]func(*parser.Block, *MatchSpec) bool{
 	IsNone: func(block *parser.Block, spec *MatchSpec) bool {
 		attribute := block.GetAttribute(spec.Name)
 		if attribute == nil {
-			return true
+			return spec.IgnoreUndefined
 		}
 		return attribute.IsNone(unpackInterfaceToInterfaceSlice(spec.MatchValue)...)
 	},
@@ -115,8 +115,10 @@ func processFoundChecks(checks ChecksFile) {
 			scanner.RegisterCheck(scanner.Check{
 				Code: customCheck.Code,
 				Documentation: scanner.CheckDocumentation{
-					Summary: scanner.RuleSummary(customCheck.Description),
-					Links:   customCheck.RelatedLinks,
+					Summary:    scanner.RuleSummary(customCheck.Description),
+					Links:      customCheck.RelatedLinks,
+					Impact:     customCheck.Impact,
+					Resolution: customCheck.Resolution,
 				},
 				Provider:       "custom",
 				RequiredTypes:  customCheck.RequiredTypes,
@@ -148,7 +150,11 @@ func evalMatchSpec(block *parser.Block, spec *MatchSpec, ctx *scanner.Context) b
 		return block.InModule()
 	}
 	if spec.Action == RegexMatches && !matchFunctions[RegexMatches](block, spec) {
-		return false
+		return spec.IgnoreUnmatched
+	}
+
+	if spec.Action == HasTag {
+		return checkTags(block, spec, ctx)
 	}
 
 	if spec.Action == RequiresPresence {
@@ -203,10 +209,37 @@ func unpackInterfaceToInterfaceSlice(t interface{}) []interface{} {
 	switch t := t.(type) {
 	case []interface{}:
 		var result []interface{}
-		for _, i := range t {
-			result = append(result, i)
-		}
-		return result
+		return append(result, t...)
 	}
 	return nil
 }
+
+func checkTags(block *parser.Block, spec *MatchSpec, ctx *scanner.Context) bool {
+	expectedTag := fmt.Sprintf("%v", spec.MatchValue)
+
+	if block.HasChild("tags") {
+		tagsBlock := block.GetAttribute("tags")
+		if tagsBlock.Contains(expectedTag) {
+			return true
+		}
+	}
+
+	var alias string
+	if block.HasChild("provider") {
+		alias = block.GetAttribute("provider").ReferenceAsString()
+	}
+
+	awsProviders := ctx.GetProviderBlocksByProvider("aws", alias)
+	for _, providerBlock := range awsProviders {
+		if providerBlock.HasChild("default_tags") {
+			defaultTags := providerBlock.GetBlock("default_tags")
+			if defaultTags.HasChild("tags") {
+				tags := defaultTags.GetAttribute("tags")
+				if tags.Contains(expectedTag) {
+					return true
+				}
+			}
+		}
+	}
+	return false
+}
